import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { CarouselIndicatorsOrientation_$type } from "./CarouselIndicatorsOrientation";
import { CarouselAnimationType_$type } from "./CarouselAnimationType";
import { IgrNumberEventArgs } from "./igr-number-event-args";
import { IgrVoidEventArgs } from "./igr-void-event-args";
import { Carousel } from "./Carousel";
import { TypeRegistrar } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { IgcCarouselComponent, defineComponents } from "igniteui-webcomponents";
import { NamePatcher, getModifiedProps, isValidProp, ensureBool, ensureEnum, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
/**
 * The `igc-carousel` presents a set of `igc-carousel-slide`s by sequentially displaying a subset of one or more slides.
*/
export class IgrCarousel extends React.Component {
    createImplementation() {
        return new Carousel();
    }
    get nativeElement() {
        return this._implementation.nativeElement;
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    constructor(props) {
        super(props);
        this.mounted = false;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        this._slideChanged = null;
        this._slideChanged_wrapped = null;
        this._playing = null;
        this._playing_wrapped = null;
        this._paused = null;
        this._paused_wrapped = null;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcCarouselComponent);
        this._implementation = this.createImplementation();
        this._portalManager = new PortalManager("templates", () => {
            if (this.mounted) {
                this.setState({});
            }
        });
        if (typeof window !== 'undefined' && typeof document !== 'undefined') {
            this._renderer = new ReactRenderer(this._implementation.nativeElement, document, false, null, this._portalManager);
        }
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    render() {
        const nativePropsName = Object.keys(this.props).filter(prop => !isValidProp(this, prop) && prop !== "originalRef" && prop !== "className");
        const nativeProps = {};
        nativePropsName.forEach(propName => {
            nativeProps[propName] = this.props[propName];
        });
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        let style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        let div = React.createElement("igc-carousel", Object.assign(Object.assign({}, nativeProps), { ref: this._getMainRef, id: this.props.id, class: this.props.className, style: style, children: children }));
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * Whether the carousel should skip rotating to the first slide after it reaches the last.
    */
    get disableLoop() {
        return this.i.h;
    }
    set disableLoop(v) {
        this.i.h = ensureBool(v);
    }
    /**
     * Whether the carousel should ignore use interactions and not pause on them.
    */
    get disablePauseOnInteraction() {
        return this.i.i;
    }
    set disablePauseOnInteraction(v) {
        this.i.i = ensureBool(v);
    }
    /**
     * Whether the carousel should skip rendering of the default navigation buttons.
    */
    get hideNavigation() {
        return this.i.k;
    }
    set hideNavigation(v) {
        this.i.k = ensureBool(v);
    }
    /**
     * Whether the carousel should render the indicator controls (dots).
    */
    get hideIndicators() {
        return this.i.j;
    }
    set hideIndicators(v) {
        this.i.j = ensureBool(v);
    }
    /**
     * Whether the carousel has vertical alignment.
    */
    get vertical() {
        return this.i.q;
    }
    set vertical(v) {
        this.i.q = ensureBool(v);
    }
    /**
     * Sets the orientation of the indicator controls (dots).
    */
    get indicatorsOrientation() {
        return this.i.b;
    }
    set indicatorsOrientation(v) {
        this.i.b = ensureEnum(CarouselIndicatorsOrientation_$type, v);
    }
    /**
     * The format used to set the aria-label on the carousel indicators.
     * Instances of '{0}' will be replaced with the index of the corresponding slide.
    */
    get indicatorsLabelFormat() {
        return this.i.x;
    }
    set indicatorsLabelFormat(v) {
        this.i.x = v;
    }
    /**
     * The format used to set the aria-label on the carousel slides and the text displayed
     * when the number of indicators is greater than tha maximum indicator count.
     * Instances of '{0}' will be replaced with the index of the corresponding slide.
     * Instances of '{1}' will be replaced with the total amount of slides.
    */
    get slidesLabelFormat() {
        return this.i.y;
    }
    set slidesLabelFormat(v) {
        this.i.y = v;
    }
    /**
     * The duration in milliseconds between changing the active slide.
    */
    get interval() {
        return this.i.s;
    }
    set interval(v) {
        this.i.s = +v;
    }
    /**
     * Controls the maximum indicator controls (dots) that can be shown. Default value is `10`.
    */
    get maximumIndicatorsCount() {
        return this.i.t;
    }
    set maximumIndicatorsCount(v) {
        this.i.t = +v;
    }
    /**
     * The animation type.
    */
    get animationType() {
        return this.i.a;
    }
    set animationType(v) {
        this.i.a = ensureEnum(CarouselAnimationType_$type, v);
    }
    /**
     * The total number of slides.
    */
    get total() {
        return this.i.u;
    }
    /**
     * The index of the current active slide.
    */
    get current() {
        return this.i.r;
    }
    /**
     * Whether the carousel is in playing state.
    */
    get isPlaying() {
        return this.i.m;
    }
    /**
     * Whether the carousel in in paused state.
    */
    get isPaused() {
        return this.i.l;
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("Carousel");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
    setNativeElement(element) {
        this.i.setNativeElement(element);
    }
    /**
     * Resumes playing of the carousel slides.
    
    */
    play() {
        this.i.ab();
    }
    /**
     * Pauses the carousel rotation of slides.
    
    */
    pause() {
        this.i.z();
    }
    /**
     * Switches to the next slide, runs any animations, and returns if the operation was successful.
    
    */
    next() {
        let iv = this.i.n();
        return (iv);
    }
    /**
     * Switches to the previous slide, runs any animations, and returns if the operation was successful.
    
    */
    prev() {
        let iv = this.i.o();
        return (iv);
    }
    select(index, animationDirection) {
        let iv = this.i.p(index, (animationDirection == null ? null : animationDirection));
        return (iv);
    }
    get slideChanged() {
        return this._slideChanged;
    }
    set slideChanged(ev) {
        if (this._slideChanged_wrapped !== null) {
            this.i.slideChanged = delegateRemove(this.i.slideChanged, this._slideChanged_wrapped);
            this._slideChanged_wrapped = null;
            this._slideChanged = null;
        }
        this._slideChanged = ev;
        this._slideChanged_wrapped = (o, e) => {
            let outerArgs = new IgrNumberEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforeSlideChanged) {
                this.beforeSlideChanged(this, outerArgs);
            }
            if (this._slideChanged) {
                this._slideChanged(this, outerArgs);
            }
        };
        this.i.slideChanged = delegateCombine(this.i.slideChanged, this._slideChanged_wrapped);
        if (this.i.slideChangedChanged) {
            this.i.slideChangedChanged();
        }
        ;
    }
    get playing() {
        return this._playing;
    }
    set playing(ev) {
        if (this._playing_wrapped !== null) {
            this.i.playing = delegateRemove(this.i.playing, this._playing_wrapped);
            this._playing_wrapped = null;
            this._playing = null;
        }
        this._playing = ev;
        this._playing_wrapped = (o, e) => {
            let outerArgs = new IgrVoidEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforePlaying) {
                this.beforePlaying(this, outerArgs);
            }
            if (this._playing) {
                this._playing(this, outerArgs);
            }
        };
        this.i.playing = delegateCombine(this.i.playing, this._playing_wrapped);
        if (this.i.playingChanged) {
            this.i.playingChanged();
        }
        ;
    }
    get paused() {
        return this._paused;
    }
    set paused(ev) {
        if (this._paused_wrapped !== null) {
            this.i.paused = delegateRemove(this.i.paused, this._paused_wrapped);
            this._paused_wrapped = null;
            this._paused = null;
        }
        this._paused = ev;
        this._paused_wrapped = (o, e) => {
            let outerArgs = new IgrVoidEventArgs();
            outerArgs._provideImplementation(e);
            if (this.beforePaused) {
                this.beforePaused(this, outerArgs);
            }
            if (this._paused) {
                this._paused(this, outerArgs);
            }
        };
        this.i.paused = delegateCombine(this.i.paused, this._paused_wrapped);
        if (this.i.pausedChanged) {
            this.i.pausedChanged();
        }
        ;
    }
}
