import { __assign, __extends, __values } from "tslib";
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { CarouselIndicatorsOrientation_$type } from "./CarouselIndicatorsOrientation";
import { CarouselAnimationType_$type } from "./CarouselAnimationType";
import { IgrNumberEventArgs } from "./igr-number-event-args";
import { IgrVoidEventArgs } from "./igr-void-event-args";
import { Carousel } from "./Carousel";
import { TypeRegistrar } from "igniteui-react-core";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { IgcCarouselComponent, defineComponents } from "igniteui-webcomponents";
import { NamePatcher, getModifiedProps, isValidProp, ensureBool, ensureEnum, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
/**
 * The `igc-carousel` presents a set of `igc-carousel-slide`s by sequentially displaying a subset of one or more slides.
*/
var IgrCarousel = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrCarousel, _super);
    function IgrCarousel(props) {
        var _this = _super.call(this, props) || this;
        _this.mounted = false;
        _this.__p = null;
        _this._hasUserValues = new Set();
        _this._stylingContainer = null;
        _this._stylingParent = null;
        _this._inStyling = false;
        _this._slideChanged = null;
        _this._slideChanged_wrapped = null;
        _this._playing = null;
        _this._playing_wrapped = null;
        _this._paused = null;
        _this._paused_wrapped = null;
        if (_this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(_this));
        }
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcCarouselComponent);
        _this._implementation = _this.createImplementation();
        _this._portalManager = new PortalManager("templates", function () {
            if (_this.mounted) {
                _this.setState({});
            }
        });
        if (typeof window !== 'undefined' && typeof document !== 'undefined') {
            _this._renderer = new ReactRenderer(_this._implementation.nativeElement, document, false, null, _this._portalManager);
        }
        _this._implementation.externalObject = _this;
        _this.onImplementationCreated();
        if (_this._initializeAdapters) {
            _this._initializeAdapters();
        }
        return _this;
    }
    IgrCarousel.prototype.createImplementation = function () {
        return new Carousel();
    };
    Object.defineProperty(IgrCarousel.prototype, "nativeElement", {
        get: function () {
            return this._implementation.nativeElement;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        } /**
                                     * @hidden
                                     */,
        enumerable: false,
        configurable: true
    });
    IgrCarousel._createFromInternal = function (internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        var name = internal.$type.name;
        var externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    };
    IgrCarousel.prototype.onImplementationCreated = function () {
    };
    IgrCarousel.prototype.componentDidMount = function () {
        var e_1, _a;
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        try {
            for (var _b = __values(Object.keys(this.props)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = this.props[p];
                }
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
    };
    IgrCarousel.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        var e_2, _a;
        var mod = getModifiedProps(this.props, nextProps);
        try {
            for (var _b = __values(Object.keys(mod)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = mod[p];
                }
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        return true;
    };
    IgrCarousel.prototype.render = function () {
        var _this = this;
        var nativePropsName = Object.keys(this.props).filter(function (prop) { return !isValidProp(_this, prop) && prop !== "originalRef" && prop !== "className"; });
        var nativeProps = {};
        nativePropsName.forEach(function (propName) {
            nativeProps[propName] = _this.props[propName];
        });
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-carousel", __assign(__assign({}, nativeProps), { ref: this._getMainRef, id: this.props.id, class: this.props.className, style: style, children: children }));
        return div;
    };
    IgrCarousel.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrCarousel.prototype, "disableLoop", {
        /**
         * Whether the carousel should skip rotating to the first slide after it reaches the last.
        */
        get: function () {
            return this.i.h;
        },
        set: function (v) {
            this.i.h = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "disablePauseOnInteraction", {
        /**
         * Whether the carousel should ignore use interactions and not pause on them.
        */
        get: function () {
            return this.i.i;
        },
        set: function (v) {
            this.i.i = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "hideNavigation", {
        /**
         * Whether the carousel should skip rendering of the default navigation buttons.
        */
        get: function () {
            return this.i.k;
        },
        set: function (v) {
            this.i.k = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "hideIndicators", {
        /**
         * Whether the carousel should render the indicator controls (dots).
        */
        get: function () {
            return this.i.j;
        },
        set: function (v) {
            this.i.j = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "vertical", {
        /**
         * Whether the carousel has vertical alignment.
        */
        get: function () {
            return this.i.q;
        },
        set: function (v) {
            this.i.q = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "indicatorsOrientation", {
        /**
         * Sets the orientation of the indicator controls (dots).
        */
        get: function () {
            return this.i.b;
        },
        set: function (v) {
            this.i.b = ensureEnum(CarouselIndicatorsOrientation_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "indicatorsLabelFormat", {
        /**
         * The format used to set the aria-label on the carousel indicators.
         * Instances of '{0}' will be replaced with the index of the corresponding slide.
        */
        get: function () {
            return this.i.x;
        },
        set: function (v) {
            this.i.x = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "slidesLabelFormat", {
        /**
         * The format used to set the aria-label on the carousel slides and the text displayed
         * when the number of indicators is greater than tha maximum indicator count.
         * Instances of '{0}' will be replaced with the index of the corresponding slide.
         * Instances of '{1}' will be replaced with the total amount of slides.
        */
        get: function () {
            return this.i.y;
        },
        set: function (v) {
            this.i.y = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "interval", {
        /**
         * The duration in milliseconds between changing the active slide.
        */
        get: function () {
            return this.i.s;
        },
        set: function (v) {
            this.i.s = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "maximumIndicatorsCount", {
        /**
         * Controls the maximum indicator controls (dots) that can be shown. Default value is `10`.
        */
        get: function () {
            return this.i.t;
        },
        set: function (v) {
            this.i.t = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "animationType", {
        /**
         * The animation type.
        */
        get: function () {
            return this.i.a;
        },
        set: function (v) {
            this.i.a = ensureEnum(CarouselAnimationType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "total", {
        /**
         * The total number of slides.
        */
        get: function () {
            return this.i.u;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "current", {
        /**
         * The index of the current active slide.
        */
        get: function () {
            return this.i.r;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "isPlaying", {
        /**
         * Whether the carousel is in playing state.
        */
        get: function () {
            return this.i.m;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "isPaused", {
        /**
         * Whether the carousel in in paused state.
        */
        get: function () {
            return this.i.l;
        },
        enumerable: false,
        configurable: true
    });
    IgrCarousel.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    };
    Object.defineProperty(IgrCarousel.prototype, "hasUserValues", {
        get: function () {
            return this._hasUserValues;
        },
        enumerable: false,
        configurable: true
    });
    IgrCarousel.prototype.__m = function (propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    };
    IgrCarousel.prototype._styling = function (container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        var genericPrefix = "";
        var typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("Carousel");
        var additionalPrefixes = [];
        var prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        var b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            var basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            var parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            var parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    };
    IgrCarousel.prototype.setNativeElement = function (element) {
        this.i.setNativeElement(element);
    };
    /**
     * Resumes playing of the carousel slides.
    
    */
    IgrCarousel.prototype.play = function () {
        this.i.ab();
    };
    /**
     * Pauses the carousel rotation of slides.
    
    */
    IgrCarousel.prototype.pause = function () {
        this.i.z();
    };
    /**
     * Switches to the next slide, runs any animations, and returns if the operation was successful.
    
    */
    IgrCarousel.prototype.next = function () {
        var iv = this.i.n();
        return (iv);
    };
    /**
     * Switches to the previous slide, runs any animations, and returns if the operation was successful.
    
    */
    IgrCarousel.prototype.prev = function () {
        var iv = this.i.o();
        return (iv);
    };
    IgrCarousel.prototype.select = function (index, animationDirection) {
        var iv = this.i.p(index, (animationDirection == null ? null : animationDirection));
        return (iv);
    };
    Object.defineProperty(IgrCarousel.prototype, "slideChanged", {
        get: function () {
            return this._slideChanged;
        },
        set: function (ev) {
            var _this = this;
            if (this._slideChanged_wrapped !== null) {
                this.i.slideChanged = delegateRemove(this.i.slideChanged, this._slideChanged_wrapped);
                this._slideChanged_wrapped = null;
                this._slideChanged = null;
            }
            this._slideChanged = ev;
            this._slideChanged_wrapped = function (o, e) {
                var outerArgs = new IgrNumberEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeSlideChanged) {
                    _this.beforeSlideChanged(_this, outerArgs);
                }
                if (_this._slideChanged) {
                    _this._slideChanged(_this, outerArgs);
                }
            };
            this.i.slideChanged = delegateCombine(this.i.slideChanged, this._slideChanged_wrapped);
            if (this.i.slideChangedChanged) {
                this.i.slideChangedChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "playing", {
        get: function () {
            return this._playing;
        },
        set: function (ev) {
            var _this = this;
            if (this._playing_wrapped !== null) {
                this.i.playing = delegateRemove(this.i.playing, this._playing_wrapped);
                this._playing_wrapped = null;
                this._playing = null;
            }
            this._playing = ev;
            this._playing_wrapped = function (o, e) {
                var outerArgs = new IgrVoidEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforePlaying) {
                    _this.beforePlaying(_this, outerArgs);
                }
                if (_this._playing) {
                    _this._playing(_this, outerArgs);
                }
            };
            this.i.playing = delegateCombine(this.i.playing, this._playing_wrapped);
            if (this.i.playingChanged) {
                this.i.playingChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrCarousel.prototype, "paused", {
        get: function () {
            return this._paused;
        },
        set: function (ev) {
            var _this = this;
            if (this._paused_wrapped !== null) {
                this.i.paused = delegateRemove(this.i.paused, this._paused_wrapped);
                this._paused_wrapped = null;
                this._paused = null;
            }
            this._paused = ev;
            this._paused_wrapped = function (o, e) {
                var outerArgs = new IgrVoidEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforePaused) {
                    _this.beforePaused(_this, outerArgs);
                }
                if (_this._paused) {
                    _this._paused(_this, outerArgs);
                }
            };
            this.i.paused = delegateCombine(this.i.paused, this._paused_wrapped);
            if (this.i.pausedChanged) {
                this.i.pausedChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrCarousel;
}(React.Component));
export { IgrCarousel };
