import * as React from 'react';
import { CalendarHeaderOrientation } from "./CalendarHeaderOrientation";
import { CalendarOrientation } from "./CalendarOrientation";
import { CalendarActiveView } from "./CalendarActiveView";
import { IgrCalendarFormatOptions } from "./igr-calendar-format-options";
import { IgrCalendarResourceStrings } from "./igr-calendar-resource-strings";
import { IgrComponentDataValueChangedEventArgs } from "./igr-component-data-value-changed-event-args";
import { IgrCalendarBase, IIgrCalendarBaseProps } from "./igr-calendar-base";
import { Calendar } from "./Calendar";
/**
 * Represents a calendar that lets users
 * to select a date value in a variety of different ways.
*/
export declare class IgrCalendar extends IgrCalendarBase<IIgrCalendarProps & Omit<React.HTMLAttributes<HTMLElement>, keyof IIgrCalendarProps>> {
    protected createImplementation(): Calendar;
    /**
                                 * @hidden
                                 */
    get i(): Calendar;
    constructor(props: IIgrCalendarProps & Omit<React.HTMLAttributes<HTMLElement>, keyof IIgrCalendarProps>);
    componentDidMount(): void;
    render(): React.DOMElement<any, Element>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    get value(): Date;
    set value(v: Date);
    get values(): Date[];
    set values(v: Date[]);
    /**
     * Sets the date which is shown in view and is highlighted. By default it is the current date.
    */
    get activeDate(): Date;
    set activeDate(v: Date);
    /**
     * Whether to show the dates that do not belong to the current active month.
    */
    get hideOutsideDays(): boolean;
    set hideOutsideDays(v: boolean);
    /**
     * Whether to render the calendar header part.
     * When the calendar selection is set to `multiple` the header is always hidden.
    */
    get hideHeader(): boolean;
    set hideHeader(v: boolean);
    /**
     * The orientation of the calendar header.
    */
    get headerOrientation(): CalendarHeaderOrientation;
    set headerOrientation(v: CalendarHeaderOrientation);
    /**
     * The orientation of the calendar months when more than one month
     * is being shown.
    */
    get orientation(): CalendarOrientation;
    set orientation(v: CalendarOrientation);
    /**
     * The number of months displayed in the days view.
    */
    get visibleMonths(): number;
    set visibleMonths(v: number);
    /**
     * The current active view of the component.
    */
    get activeView(): CalendarActiveView;
    set activeView(v: CalendarActiveView);
    /**
     * The options used to format the months and the weekdays in the calendar views.
    */
    get formatOptions(): IgrCalendarFormatOptions;
    set formatOptions(v: IgrCalendarFormatOptions);
    /**
     * The resource strings for localization.
    */
    get resourceStrings(): IgrCalendarResourceStrings;
    set resourceStrings(v: IgrCalendarResourceStrings);
    findByName(name: string): any;
    private _change;
    private _change_wrapped;
    get change(): (s: IgrCalendar, e: IgrComponentDataValueChangedEventArgs) => void;
    set change(ev: (s: IgrCalendar, e: IgrComponentDataValueChangedEventArgs) => void);
}
export interface IIgrCalendarProps extends IIgrCalendarBaseProps {
    value?: Date;
    values?: Date[];
    /**
     * Sets the date which is shown in view and is highlighted. By default it is the current date.
    */
    activeDate?: Date;
    /**
     * Whether to show the dates that do not belong to the current active month.
    */
    hideOutsideDays?: boolean | string;
    /**
     * Whether to render the calendar header part.
     * When the calendar selection is set to `multiple` the header is always hidden.
    */
    hideHeader?: boolean | string;
    /**
     * The orientation of the calendar header.
    */
    headerOrientation?: CalendarHeaderOrientation | string;
    /**
     * The orientation of the calendar months when more than one month
     * is being shown.
    */
    orientation?: CalendarOrientation | string;
    /**
     * The number of months displayed in the days view.
    */
    visibleMonths?: number | string;
    /**
     * The current active view of the component.
    */
    activeView?: CalendarActiveView | string;
    /**
     * The options used to format the months and the weekdays in the calendar views.
    */
    formatOptions?: IgrCalendarFormatOptions;
    /**
     * The resource strings for localization.
    */
    resourceStrings?: IgrCalendarResourceStrings;
    change?: (s: IgrCalendar, e: IgrComponentDataValueChangedEventArgs) => void;
}
