import * as React from 'react';
import { CarouselIndicatorsOrientation } from "./CarouselIndicatorsOrientation";
import { CarouselAnimationType } from "./CarouselAnimationType";
import { IgrNumberEventArgs } from "./igr-number-event-args";
import { IgrVoidEventArgs } from "./igr-void-event-args";
import { CarouselAnimationDirection } from "./CarouselAnimationDirection";
import { Carousel } from "./Carousel";
import { ReactRenderer, PortalManager } from "igniteui-react-core";
import { ContentChildrenManager } from "igniteui-react-core";
/**
 * The `igc-carousel` presents a set of `igc-carousel-slide`s by sequentially displaying a subset of one or more slides.
*/
export declare class IgrCarousel<P extends IIgrCarouselProps = IIgrCarouselProps> extends React.Component<P & Omit<React.HTMLAttributes<HTMLElement>, keyof P>, {}> {
    protected createImplementation(): Carousel;
    protected _implementation: any;
    protected mounted: boolean;
    get nativeElement(): HTMLElement;
    /**
     * @hidden
     */
    get i(): Carousel; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrCarousel;
    protected _renderer: ReactRenderer;
    protected _portalManager: PortalManager;
    protected onImplementationCreated(): void;
    protected _contentChildrenManager: ContentChildrenManager;
    constructor(props: P & Omit<React.HTMLAttributes<HTMLElement>, keyof P>);
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): React.DOMElement<{
        ref: (ref: any) => void;
        id: (P & Omit<React.HTMLAttributes<HTMLElement>, keyof P>)["id"];
        class: (P & Omit<React.HTMLAttributes<HTMLElement>, keyof P>)["className"];
        style: {};
        children: any[];
    }, any>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    /**
     * Whether the carousel should skip rotating to the first slide after it reaches the last.
    */
    get disableLoop(): boolean;
    set disableLoop(v: boolean);
    /**
     * Whether the carousel should ignore use interactions and not pause on them.
    */
    get disablePauseOnInteraction(): boolean;
    set disablePauseOnInteraction(v: boolean);
    /**
     * Whether the carousel should skip rendering of the default navigation buttons.
    */
    get hideNavigation(): boolean;
    set hideNavigation(v: boolean);
    /**
     * Whether the carousel should render the indicator controls (dots).
    */
    get hideIndicators(): boolean;
    set hideIndicators(v: boolean);
    /**
     * Whether the carousel has vertical alignment.
    */
    get vertical(): boolean;
    set vertical(v: boolean);
    /**
     * Sets the orientation of the indicator controls (dots).
    */
    get indicatorsOrientation(): CarouselIndicatorsOrientation;
    set indicatorsOrientation(v: CarouselIndicatorsOrientation);
    /**
     * The format used to set the aria-label on the carousel indicators.
     * Instances of '{0}' will be replaced with the index of the corresponding slide.
    */
    get indicatorsLabelFormat(): string;
    set indicatorsLabelFormat(v: string);
    /**
     * The format used to set the aria-label on the carousel slides and the text displayed
     * when the number of indicators is greater than tha maximum indicator count.
     * Instances of '{0}' will be replaced with the index of the corresponding slide.
     * Instances of '{1}' will be replaced with the total amount of slides.
    */
    get slidesLabelFormat(): string;
    set slidesLabelFormat(v: string);
    /**
     * The duration in milliseconds between changing the active slide.
    */
    get interval(): number;
    set interval(v: number);
    /**
     * Controls the maximum indicator controls (dots) that can be shown. Default value is `10`.
    */
    get maximumIndicatorsCount(): number;
    set maximumIndicatorsCount(v: number);
    /**
     * The animation type.
    */
    get animationType(): CarouselAnimationType;
    set animationType(v: CarouselAnimationType);
    /**
     * The total number of slides.
    */
    get total(): number;
    /**
     * The index of the current active slide.
    */
    get current(): number;
    /**
     * Whether the carousel is in playing state.
    */
    get isPlaying(): boolean;
    /**
     * Whether the carousel in in paused state.
    */
    get isPaused(): boolean;
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    setNativeElement(element: any): void;
    /**
     * Resumes playing of the carousel slides.
    
    */
    play(): void;
    /**
     * Pauses the carousel rotation of slides.
    
    */
    pause(): void;
    /**
     * Switches to the next slide, runs any animations, and returns if the operation was successful.
    
    */
    next(): boolean;
    /**
     * Switches to the previous slide, runs any animations, and returns if the operation was successful.
    
    */
    prev(): boolean;
    select(index: number, animationDirection: CarouselAnimationDirection): boolean;
    private _slideChanged;
    private _slideChanged_wrapped;
    get slideChanged(): (s: IgrCarousel, e: IgrNumberEventArgs) => void;
    set slideChanged(ev: (s: IgrCarousel, e: IgrNumberEventArgs) => void);
    private _playing;
    private _playing_wrapped;
    get playing(): (s: IgrCarousel, e: IgrVoidEventArgs) => void;
    set playing(ev: (s: IgrCarousel, e: IgrVoidEventArgs) => void);
    private _paused;
    private _paused_wrapped;
    get paused(): (s: IgrCarousel, e: IgrVoidEventArgs) => void;
    set paused(ev: (s: IgrCarousel, e: IgrVoidEventArgs) => void);
}
export interface IIgrCarouselProps {
    children?: React.ReactNode;
    id?: string | undefined;
    className?: string | undefined;
    style?: React.CSSProperties | undefined;
    /**
     * Whether the carousel should skip rotating to the first slide after it reaches the last.
    */
    disableLoop?: boolean | string;
    /**
     * Whether the carousel should ignore use interactions and not pause on them.
    */
    disablePauseOnInteraction?: boolean | string;
    /**
     * Whether the carousel should skip rendering of the default navigation buttons.
    */
    hideNavigation?: boolean | string;
    /**
     * Whether the carousel should render the indicator controls (dots).
    */
    hideIndicators?: boolean | string;
    /**
     * Whether the carousel has vertical alignment.
    */
    vertical?: boolean | string;
    /**
     * Sets the orientation of the indicator controls (dots).
    */
    indicatorsOrientation?: CarouselIndicatorsOrientation | string;
    /**
     * The format used to set the aria-label on the carousel indicators.
     * Instances of '{0}' will be replaced with the index of the corresponding slide.
    */
    indicatorsLabelFormat?: string;
    /**
     * The format used to set the aria-label on the carousel slides and the text displayed
     * when the number of indicators is greater than tha maximum indicator count.
     * Instances of '{0}' will be replaced with the index of the corresponding slide.
     * Instances of '{1}' will be replaced with the total amount of slides.
    */
    slidesLabelFormat?: string;
    /**
     * The duration in milliseconds between changing the active slide.
    */
    interval?: number | string;
    /**
     * Controls the maximum indicator controls (dots) that can be shown. Default value is `10`.
    */
    maximumIndicatorsCount?: number | string;
    /**
     * The animation type.
    */
    animationType?: CarouselAnimationType | string;
    slideChanged?: (s: IgrCarousel, e: IgrNumberEventArgs) => void;
    playing?: (s: IgrCarousel, e: IgrVoidEventArgs) => void;
    paused?: (s: IgrCarousel, e: IgrVoidEventArgs) => void;
}
