import * as React from 'react';
import { IgrRangeSliderValueEventArgs } from "./igr-range-slider-value-event-args";
import { IgrSliderBase, IIgrSliderBaseProps } from "./igr-slider-base";
import { RangeSlider } from "./RangeSlider";
/**
 * A range slider component used to select two numeric values within a range.
*/
export declare class IgrRangeSlider extends IgrSliderBase<IIgrRangeSliderProps & Omit<React.HTMLAttributes<HTMLElement>, keyof IIgrRangeSliderProps>> {
    protected createImplementation(): RangeSlider;
    /**
                                 * @hidden
                                 */
    get i(): RangeSlider;
    constructor(props: IIgrRangeSliderProps & Omit<React.HTMLAttributes<HTMLElement>, keyof IIgrRangeSliderProps>);
    componentDidMount(): void;
    render(): React.DOMElement<any, Element>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    /**
     * The current value of the lower thumb.
    */
    get lower(): number;
    set lower(v: number);
    /**
     * The current value of the upper thumb.
    */
    get upper(): number;
    set upper(v: number);
    /**
     * The aria label for the lower thumb.
    */
    get thumbLabelLower(): string;
    set thumbLabelLower(v: string);
    /**
     * The aria label for the upper thumb.
    */
    get thumbLabelUpper(): string;
    set thumbLabelUpper(v: string);
    private _input;
    private _input_wrapped;
    /**
     * Emitted when a value is changed via thumb drag or keyboard interaction.
    */
    get input(): (s: IgrRangeSlider, e: IgrRangeSliderValueEventArgs) => void;
    set input(ev: (s: IgrRangeSlider, e: IgrRangeSliderValueEventArgs) => void);
    private _change;
    private _change_wrapped;
    /**
     * Emitted when a value change is committed on a thumb drag end or keyboard interaction.
    */
    get change(): (s: IgrRangeSlider, e: IgrRangeSliderValueEventArgs) => void;
    set change(ev: (s: IgrRangeSlider, e: IgrRangeSliderValueEventArgs) => void);
}
export interface IIgrRangeSliderProps extends IIgrSliderBaseProps {
    /**
     * The current value of the lower thumb.
    */
    lower?: number | string;
    /**
     * The current value of the upper thumb.
    */
    upper?: number | string;
    /**
     * The aria label for the lower thumb.
    */
    thumbLabelLower?: string;
    /**
     * The aria label for the upper thumb.
    */
    thumbLabelUpper?: string;
    /**
     * Emitted when a value is changed via thumb drag or keyboard interaction.
    */
    input?: (s: IgrRangeSlider, e: IgrRangeSliderValueEventArgs) => void;
    /**
     * Emitted when a value change is committed on a thumb drag end or keyboard interaction.
    */
    change?: (s: IgrRangeSlider, e: IgrRangeSliderValueEventArgs) => void;
}
